#!/usr/bin/env python
"""
Download utility as an easy way to get files from the net

This script is not option compatible with Unix wget utility,
to make the command line interface intuitive for new users.

Public domain by ktechhub <info@ktechhub.com>
Also available under the terms of MIT license
Copyright (c) 2024 ktechhub
"""
